Crate sal_rhai

Crate sal_rhai 

Rhai scripting integration for the SAL library

This module provides integration with the Rhai scripting language, allowing SAL functions to be called from Rhai scripts.

Re-exports

pub use error::*;

Modules

core
Rhai wrappers for core engine functions
error

Structs

Dynamic
Dynamic type containing any value.
Engine
Rhai main scripting engine.
GitRepo
Represents a git repository.
GitTree
Represents a collection of git repositories under a base path.
KubernetesManager
KubernetesManager provides namespace-scoped operations for Kubernetes resources

Enums

EvalAltResult
Evaluation result.

Functions

bah_new
Create a new Builder
delete
Wrapper for fs::delete
download
Wrapper for os::download
download_install
Wrapper for os::download_install
exist
Wrapper for fs::exist
file_size
Wrapper for fs::file_size
find_dir
Wrapper for fs::find_dir
find_dirs
Wrapper for fs::find_dirs
find_file
Wrapper for fs::find_file
find_files
Wrapper for fs::find_files
kill
Wrapper for process::kill
mkdir
Wrapper for fs::mkdir
nerdctl_copy
Wrapper for nerdctl::copy
nerdctl_exec
Wrapper for nerdctl::exec
nerdctl_image_build
Wrapper for nerdctl::image_build
nerdctl_image_commit
Wrapper for nerdctl::image_commit
nerdctl_image_pull
Wrapper for nerdctl::image_pull
nerdctl_image_push
Wrapper for nerdctl::image_push
nerdctl_image_remove
Wrapper for nerdctl::image_remove
nerdctl_image_tag
Wrapper for nerdctl::image_tag
nerdctl_images
Wrapper for nerdctl::images
nerdctl_list
Wrapper for nerdctl::list
nerdctl_remove
Wrapper for nerdctl::remove
nerdctl_run
Wrapper for nerdctl::run
nerdctl_run_with_name
Run a container with a name
nerdctl_run_with_port
Run a container with a port mapping
nerdctl_stop
Wrapper for nerdctl::stop
os_copy
Wrapper for fs::copy
process_get
Wrapper for process::process_get
process_list
Wrapper for process::process_list
register
Register all SAL modules with the Rhai engine
register_bah_module
Register Buildah module functions with the Rhai engine
register_crypto_module
Register crypto functions with the Rhai engine
register_git_module
Register Git module functions with the Rhai engine
register_kubernetes_module
Register Kubernetes module functions with the Rhai engine
register_mycelium_module
Register Mycelium module functions with the Rhai engine
register_nerdctl_module
Register Nerdctl module functions with the Rhai engine
register_net_module
Register network module functions with the Rhai engine
register_os_module
Register OS module functions with the Rhai engine
register_postgresclient_module
Register PostgreSQL client module functions with the Rhai engine
register_process_module
Register Process module functions with the Rhai engine
register_redisclient_module
Register Redis client module functions with the Rhai engine
register_rfs_module
Register RFS functions with the Rhai engine
register_text_module
Register Text module functions with the Rhai engine
register_zinit_module
Register Zinit module functions with the Rhai engine
rsync
Wrapper for fs::rsync
which
Wrapper for process::which

Type Aliases

Array
Variable-sized array of Dynamic values.
Map
A dictionary of Dynamic values with string keys.