Rhai scripting integration for the SAL library
This module provides integration with the Rhai scripting language, allowing SAL functions to be called from Rhai scripts.
Re-exports
pub use error::*;
Modules
Structs
- Dynamic
- Dynamic type containing any value.
- Engine
- Rhai main scripting engine.
- GitRepo
- Represents a git repository.
- GitTree
- Represents a collection of git repositories under a base path.
- Kubernetes
Manager - KubernetesManager provides namespace-scoped operations for Kubernetes resources
Enums
- Eval
AltResult - Evaluation result.
Functions
- bah_new
- Create a new Builder
- delete
- Wrapper for fs::delete
- download
- Wrapper for os::download
- download_
install - Wrapper for os::download_install
- exist
- Wrapper for fs::exist
- file_
size - Wrapper for fs::file_size
- find_
dir - Wrapper for fs::find_dir
- find_
dirs - Wrapper for fs::find_dirs
- find_
file - Wrapper for fs::find_file
- find_
files - Wrapper for fs::find_files
- kill
- Wrapper for process::kill
- mkdir
- Wrapper for fs::mkdir
- nerdctl_
copy - Wrapper for nerdctl::copy
- nerdctl_
exec - Wrapper for nerdctl::exec
- nerdctl_
image_ build - Wrapper for nerdctl::image_build
- nerdctl_
image_ commit - Wrapper for nerdctl::image_commit
- nerdctl_
image_ pull - Wrapper for nerdctl::image_pull
- nerdctl_
image_ push - Wrapper for nerdctl::image_push
- nerdctl_
image_ remove - Wrapper for nerdctl::image_remove
- nerdctl_
image_ tag - Wrapper for nerdctl::image_tag
- nerdctl_
images - Wrapper for nerdctl::images
- nerdctl_
list - Wrapper for nerdctl::list
- nerdctl_
remove - Wrapper for nerdctl::remove
- nerdctl_
run - Wrapper for nerdctl::run
- nerdctl_
run_ with_ name - Run a container with a name
- nerdctl_
run_ with_ port - Run a container with a port mapping
- nerdctl_
stop - Wrapper for nerdctl::stop
- os_copy
- Wrapper for fs::copy
- process_
get - Wrapper for process::process_get
- process_
list - Wrapper for process::process_list
- register
- Register all SAL modules with the Rhai engine
- register_
bah_ module - Register Buildah module functions with the Rhai engine
- register_
crypto_ module - Register crypto functions with the Rhai engine
- register_
git_ module - Register Git module functions with the Rhai engine
- register_
kubernetes_ module - Register Kubernetes module functions with the Rhai engine
- register_
mycelium_ module - Register Mycelium module functions with the Rhai engine
- register_
nerdctl_ module - Register Nerdctl module functions with the Rhai engine
- register_
net_ module - Register network module functions with the Rhai engine
- register_
os_ module - Register OS module functions with the Rhai engine
- register_
postgresclient_ module - Register PostgreSQL client module functions with the Rhai engine
- register_
process_ module - Register Process module functions with the Rhai engine
- register_
redisclient_ module - Register Redis client module functions with the Rhai engine
- register_
rfs_ module - Register RFS functions with the Rhai engine
- register_
text_ module - Register Text module functions with the Rhai engine
- register_
zinit_ module - Register Zinit module functions with the Rhai engine
- rsync
- Wrapper for fs::rsync
- which
- Wrapper for process::which